#
# spec file for package ddskk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Current version does not build with current xemacs, disable for now
%define use_xemacs 0
Name:           ddskk
Version:        20160304
Release:        3.10
Summary:        SKK (Simple Kana to Kanji Conversion Program) for Emacs
License:        GPL-2.0-or-later AND SUSE-Permissive AND SUSE-Public-Domain
Group:          Productivity/Editors/Emacs
URL:            http://openlab.ring.gr.jp/skk/ddskk.html
Source0:        https://github.com/skk-dev/ddskk/archive/%{name}-16.2_Warabitai.tar.gz
Source1:        suse-start.el
Source97:       download-dic.sh
Source98:       README.SUSE
Source99:       ddskk-rpmlintrc
# see README.SUSE for how to generate this file.
# NOTE: some dictionary files are not licenced under GPL-2.0+
# see commiters.txt
Source100:      skkdic-20200228.tar.xz
Patch2:         bugzilla-141756-workaround.patch
# PATCH-FIX-OPENSUSE or UPSTREAM -- drop build date to make build reproducible
Patch3:         ddskk-drop-build-date.patch
BuildRequires:  compface
BuildRequires:  emacs-x11
BuildRequires:  flim
BuildRequires:  w3m
BuildRequires:  xz
%if %{use_xemacs}
BuildRequires:  xemacs-flim
BuildRequires:  xemacs-packages
BuildRequires:  xemacs-semi
%endif
Requires:       apel
Requires:       emacs
Requires:       skkdic
Provides:       locale(emacs:ja)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
SKK (Simple Kana to Kanji conversion program) is a Japanese input
method for Emacs. ddskk (Daredevil SKK) is a version of SKK that is
aggressively developed.

%if %{use_xemacs}

%package -n ddskk-xemacs
Summary:        SKK (`Simple Kana to Kanji conversion program') for XEmacs
Group:          Productivity/Editors/Emacs
Requires:       skkdic
Requires:       xemacs
Requires:       xemacs-packages
Provides:       locale(xemacs:ja)

%description -n ddskk-xemacs
SKK (`Simple Kana to Kanji conversion program') is a Japanese input
method for XEmacs. ddskk ('Daredevil SKK') is a version of SKK which is
aggressively developed.

%endif

%package -n skkdic
Summary:        Main Dictionary for SKK
Group:          System/I18n/Japanese
URL:            http://openlab.ring.gr.jp/skk/dic.html
Requires(post):	info
Requires(preun):	info
Provides:       locale(scim-skk:ja)

%description -n skkdic
main dictionary for SKK

%package -n skkdic-extra
Summary:        Optional, additional dictionaries for SKK
Group:          System/I18n/Japanese
URL:            http://openlab.ring.gr.jp/skk/dic.html

%description -n skkdic-extra
optional, additional dictionaries for SKK

%prep
%setup -q -n ddskk-ddskk-16.2_Warabitai
%patch2 -p1
%patch3 -p1
tar --strip-components=1 --xz -xf %{S:100} -C dic
cp dic/zipcode/SKK-JISYO.* dic/

%build
%define emacs_sitelisp_dir %{_datadir}/emacs/site-lisp
%define emacs_package_dir %{emacs_sitelisp_dir}/skk
(cat >> SKK-CFG)<<-'EOF'
	(setq PREFIX "%{buildroot}%{_prefix}")
	(setq SKK_DATADIR "%{buildroot}%{_datadir}/skk")
	(setq SKK_INFODIR "%{buildroot}%{_infodir}")
	(setq APEL_DIR "%{buildroot}%{emacs_sitelisp_dir}/apel")
	(setq SKK_LISPDIR "%{buildroot}%{emacs_package_dir}")
	EOF
export LANG=ja_JP.UTF-8
make EMACS=emacs %{?_smp_mflags}

%install
export LANG=ja_JP.UTF-8
mkdir -p %{buildroot}%{emacs_package_dir}
make EMACS=emacs install
(cat > %{buildroot}%{emacs_sitelisp_dir}/suse-start-%{name}.el)<<-'EOF'
	;; %{emacs_sitelisp_dir}/suse-start-%{name}.el
	(add-to-list 'load-path "%{emacs_package_dir}")
	EOF
cat %{_sourcedir}/suse-start.el >> %{buildroot}%{emacs_sitelisp_dir}/suse-start-%{name}.el
(cat >> %{buildroot}%{emacs_sitelisp_dir}/suse-start-%{name}.el)<<-'EOF'
	;; %{emacs_sitelisp_dir}/suse-start-%{name}.el ends here
	EOF
######################################################################
%if %{use_xemacs}
# now build for XEmacs:
%define xemacs_package_dir %{_datadir}/xemacs/site-packages/
make clean
sed -ri 's@\(setq[[:blank:]].*\)@@' SKK-CFG
(cat >> SKK-CFG)<<-'EOF'
	(setq PREFIX "%{buildroot}%{_prefix}")
	(setq SKK_DATADIR "%{buildroot}%{_datadir}/skk")
	(setq SKK_INFODIR "%{buildroot}%{xemacs_package_dir}/info")
	(setq APEL_DIR "%{buildroot}%{xemacs_package_dir}/lisp/apel")
	(setq SKK_LISPDIR "%{buildroot}%{xemacs_package_dir}/lisp/skk")
	(setq PACKAGEDIR "%{buildroot}%{xemacs_package_dir}")
	EOF
make EMACS=xemacs %{?_smp_mflags}
make EMACS=xemacs install-package
gzip %{buildroot}%{xemacs_package_dir}/info/skk*.info*

# It would be wasteful if XEmacs had it's own copy of the dictionaries
# and some other files. The whole %{xemacs_package_dir}/etc/skk
# can be shared with Emacs.
rm -rf %{buildroot}%{xemacs_package_dir}%{_sysconfdir}/skk
ln -s %{_datadir}/skk %{buildroot}%{xemacs_package_dir}%{_sysconfdir}/skk
# the info pages are in the skkdic package to be able to share them
# for Emacs and XEmacs:
rm -f %{buildroot}%{xemacs_package_dir}/info/skk*
# replace buildroot in comments in .elc files by spaces with the same total length:
RPM_BUILD_ROOT_REPLACEMENT=$(echo %{buildroot} | tr [:print:] ' ')
for i in $(find %{buildroot} -name "*.elc")
do
    perl -pi -e "s|(;;; from file )%{buildroot}(%{_datadir}/xemacs/site-packages/.*)|\1%{buildroot}\2|" $i
done
%endif
# remove buildroot in .el files
perl -pi -e "s|%{buildroot}||" %{buildroot}%{emacs_package_dir}/skk-setup.el

rm -vf %{buildroot}%{_infodir}/dir
%if %{use_xemacs}
rm -vf %{buildroot}%{xemacs_package_dir}/info/dir
%endif
mv READMEs/INSTALL .

%post
%install_info --info-dir=%{_infodir} %{_infodir}/skk.info

%preun
if test $1 = 0; then
   %install_info_delete --info-dir=%{_infodir} %{_infodir}/skk.info
fi

%files
%defattr(-,root,root)
%doc ChangeLog* READMEs
%{emacs_package_dir}
%config %{emacs_sitelisp_dir}/suse-start-%{name}.el
%{_infodir}/*
%exclude %{_datadir}/doc/packages/ddskk/READMEs/README.MacOSX.ja
%exclude %{_datadir}/doc/packages/ddskk/READMEs/README.w32.ja.org

%if %{use_xemacs}
%files -n ddskk-xemacs
%defattr(-,root,root)
%doc ChangeLog* READMEs
%dir %{xemacs_package_dir}/
%dir %{xemacs_package_dir}/lisp/
%dir %{xemacs_package_dir}%{_sysconfdir}/
%{xemacs_package_dir}/lisp/*
%{xemacs_package_dir}%{_sysconfdir}/*
%endif

%files -n skkdic
%defattr(-,root,root)
%doc dic/ChangeLog*
%license dic/committers.txt
%dir %{_datadir}/skk/
%{_datadir}/skk/SKK-JISYO.L
%{_datadir}/skk/skk.xpm
%{_datadir}/skk/SKK.tut
%{_datadir}/skk/SKK.tut.E

%files -n skkdic-extra
%defattr(-,root,root)
%dir %{_datadir}/skk/
%{_datadir}/skk/SKK-JISYO.ML
%{_datadir}/skk/SKK-JISYO.M
%{_datadir}/skk/SKK-JISYO.zipcode
%{_datadir}/skk/SKK-JISYO.office.zipcode
# SUSE-Permissive
%{_datadir}/skk/SKK-JISYO.pubdic+
%{_datadir}/skk/SKK-JISYO.JIS3_4
%{_datadir}/skk/SKK-JISYO.JIS2
%{_datadir}/skk/SKK-JISYO.S
%{_datadir}/skk/SKK-JISYO.JIS2004
%{_datadir}/skk/SKK-JISYO.assoc
%{_datadir}/skk/SKK-JISYO.china_taiwan
%{_datadir}/skk/SKK-JISYO.edict
%{_datadir}/skk/SKK-JISYO.fullname
%{_datadir}/skk/SKK-JISYO.geo
%{_datadir}/skk/SKK-JISYO.itaiji
%{_datadir}/skk/SKK-JISYO.itaiji.JIS3_4
%{_datadir}/skk/SKK-JISYO.jinmei
%{_datadir}/skk/SKK-JISYO.law
%{_datadir}/skk/SKK-JISYO.lisp
%{_datadir}/skk/SKK-JISYO.mazegaki
%{_datadir}/skk/SKK-JISYO.okinawa
%{_datadir}/skk/SKK-JISYO.propernoun
%{_datadir}/skk/SKK-JISYO.requested
%{_datadir}/skk/SKK-JISYO.station
%{_datadir}/skk/NICOLA-SKK.tut

%changelog
* Mon Mar  2 2020 Xu Zhao <i@xuzhao.net>
- Update to skkdic 20200228
  * SKK-JISYO.L: Modify below candidates.
  - よもつひらさか /黄泉平坂/{->黄泉比良坂;古事記/泉津平坂;日本書紀/}
  - やつめうなぎ /八目鰻{鱧/->}/
  - ばっさい /伐採/{伐裁/->}
  - せんけん /先遣/先見/専権/先験/浅見/淺見;「浅」旧字/先件/嬋娟;-たる美女/仙建/擅権/選研/選鉱{精->製}錬研究所;※abbrev/
  - よいざm /酔い覚{;->}/酔い醒/酔醒/
  * SKK-JISYO.L: Remove below candidates.
  - かみきょうく /上京区/
  - にしぎょうく /西京区/
  - さいきょうく /西京区/
  - ちゅうきょうく /中京区/
  - しゅんとうぐん /駿東郡/
  * SKK-JISYO.L: Add below candidates.
  - うきょうく /右京区/
  - かみぎょうく /上京区/
  - しもぎょうく /下京区/
  - なかぎょうく /中京区/
  - にしきょうく /西京区/
  - ひがしやまく /東山区/
  - すんとうぐん /駿東郡/
* Thu Mar  8 2018 ftake@geeko.jp
- Remove unnecessary script: SKK-JISYO.rb
- Add download-dic.sh to Source
* Wed Mar  7 2018 ftake@geeko.jp
- Update to ddskk-16.2
  * Drop support for GNU Emacs 22
  * Support GNU Emacs 26
  * bayesian/bskk: Support Ruby 2.4
  * A New variable, skk-candidate-buffer-delete-other-windows
    for users of popwin.el or shackle.el
  * A New variable, skk-show-candidates-nth-henkan-char
    to configure the number of space keys to show a candidate list
  * A New variable, skk-henkan-number-to-display-candidates
    to specify the number of candidates on a candidate list at once
    obsoleting skk-henkan-show-candidates-rows
- Update to ddskk-16.1
  * Support GNU Emacs 25
  * Update documents
- Update dictionary to 20180304
- Drop edict dictionary
  * edict is now considered as non-free
- Remove unnecessary documents
- Fix License tag since some dictionary files are not distributed
  under GPL-2.0+
- Update the source code URL to GitHub
* Tue Feb 20 2018 crrodriguez@opensuse.org
- remove unused xorg-x11-devel BuildRequires
* Sat Aug 12 2017 bwiedemann@suse.com
- Add ddskk-drop-build-date.patch to fix build-compare (boo#1047218)
* Fri Aug 21 2015 i@marguerite.su
- update version 20150816
  * dictionaries version 20150821
  * wiki version 20150326
  * changes see ChangeLog.5
* Mon Jun  9 2014 i@marguerite.su
- update version 20140608
  * changes see ChangeLog.4 and ChangeLog.5
- drop flavour.patch
  * upstream now doesn't have this code
- drop skk-emacs-type.patch, upstreamed
* Fri May 30 2014 jengelh@inai.de
- Drop unused build-time requirements on libpng, libgif, libtiff,
  krb5, openldap2
* Wed Oct 10 2012 werner@suse.de
- Solve update problem due date based version number scheme and
  current number scheme with 14.4
* Wed Jul  4 2012 werner@suse.de
- Update to ddskk-14.4 and skkdic-20110529
  * Don't know to much as I do not speak nor read Japanese but
    it compiles with latest emacs 24.1
- Take some patches from Debian as well add some own patches
- Drop superfluous patches
* Fri Jan  6 2012 pgajdos@suse.com
- remove %%{_infodir}/* from skkdic %%files section, it is packaged
  in main package yet
* Wed Oct 26 2011 ftake@geeko.jp
- fix bnc#724242 - skk-autoloads.el is newer than byte-compiled file
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Aug 27 2009 aj@suse.de
- Use xemacs-packages instead of apel-xemacs as requirement.
- Disable building for xemacs for now since the current xemacs does
  not byte-compile everything.
* Tue Dec  4 2007 mfabian@suse.de
- remove openldap2 from BuildRequires.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(...)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 mfabian@suse.de
- bugzilla #141756: add a workaround to make the package build.
* Thu Jan 27 2005 mfabian@suse.de
- move info pages to skkdic subpackage and delete the copy
  of the info pages in the XEmacs package directory to same some
  space. On top of that the copy in the XEmacs package directory
  was broken, texinfo.el could not format it correctly, the copy
  produced by the Emacs build is correct.
* Thu Jan 27 2005 mfabian@suse.de
- new package: ddskk, version 20050123.
